/**
 * dte.h
 * =====
 * Interface to a simple Decision Tree Evaluator.
 *
 * By Hkan L. Younes (lorens@acm.org)
 */

#ifndef DTE_H
#define DTE_H


/**
 * Handle for a decision tree object.
 */
typedef struct decision_tree *DecisionTree;


/**
 * Reads a decision tree structure from file.
 *
 * Parameters:
 *  path - path to file containing the decision tree structure.
 *
 * Returns a handle for the decision tree.
 */
extern DecisionTree readTree(const char *path);

/**
 * Frees a decision tree.
 *
 * Parameters:
 *  tree - handle for tree to free.
 */
extern void freeTree(DecisionTree tree);

/**
 * Sets values in a decision tree.
 *
 * Parameters:
 *  tree    - handle for tree to set values in.
 *  first   - index of first value to set.
 *  nvalues - number of values to set.
 *  values  - the values.
 */
extern void setValues(DecisionTree tree,
		      int first, int n, const double *values);

/**
 * Evaluates a decision tree.
 *
 * Parameters:
 *  tree - handle for tree to evaluate.
 *
 * Returns the index of the "best" alternative.  If several alternatives
 * are equaly good the index of one of them is returned.
 */
extern int evaluateTree(DecisionTree tree);


#endif /* DTE_H */
