/**
 * dte_pronouncer.h
 * ================
 * Interface to basic pronouncer functionality based on DTE.
 *
 * By Hkan L. Younes (lorens@acm.org)
 */

#ifndef DTE_PRONOUNCER_H
#define DTE_PRONOUNCER_H

/**
 * Initialize pronouncer.
 *
 * Returns -1 on failure, and 0 on success.
 *
 * N.B. must be called before the pronouncer is used.
 */
extern int initializePronouncer(void);


/**
 * Finalizes pronouncer.
 *
 * N.B. should be called after the last call to the pronouncer.
 */
extern void finalizePronouncer(void);


/**
 * Loads a model.
 *
 * Parameters:
 *  path - path to file containing the model.
 *
 * Returns -1 on failure, and an identifier for the model on success.
 */
extern int loadModel(const char *path);


/**
 * Frees a model.
 *
 * Parameters:
 *  modelId - a model identifier as returned by loadModel.
 */
extern void freeModel(int modelId);


/**
 * Sets values in the given model.
 *
 * Parameters:
 *  modelId - a model identifier as returned by loadModel.
 *  first   - index of first value to set.
 *  nvalues - number of values to set.
 *  values  - the values.
 */
extern void setModelValues(int modelId, int first, int nvalues,
			   const double *values);


/**
 * Evaluates the given model.
 *
 * Parameters:
 *  modelId - a model identifier as returned by loadModel.
 *
 * Returns the index of an alternative that maximizes the expected utility.
 */
extern int evaluateModel(int modelId);

#endif /* DTE_PRONOUNCER_H */
